aboutsummaryrefslogtreecommitdiffstats
path: root/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
diff options
context:
space:
mode:
authorDylanB95EST <dylan.byrne@est.tech>2022-01-27 17:12:52 +0000
committerDylan Byrne <dylan.byrne@est.tech>2022-03-01 16:17:16 +0000
commite557338803286d8aaa0f877aa25d52d18735f309 (patch)
tree059b68301b3e6c34d8bb68a8cb7dadf6bed45a06 /cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
parent03459a08895ecc7e481fc5ec34779556268992f1 (diff)
Create Endpoint For Get Cm Handles By Name
Create endpoint and implement logic for get cm handle details by cm handle name Issue-ID: CPS-817 Change-Id: I83bd2da9219d13fac715a08b19108028ca6f6751 Signed-off-by: DylanB95EST <dylan.byrne@est.tech>
Diffstat (limited to 'cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java')
-rw-r--r--cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java25
1 files changed, 17 insertions, 8 deletions
diff --git a/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java b/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
index 5d2ab5339..471e97e08 100644
--- a/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
+++ b/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
@@ -26,6 +26,7 @@ import static org.onap.cps.ncmp.api.impl.operations.DmiRequestBody.OperationEnum
import java.util.Collection;
import org.onap.cps.ncmp.api.models.DmiPluginRegistration;
+import org.onap.cps.ncmp.api.models.NcmpServiceCmHandle;
import org.onap.cps.spi.model.ModuleReference;
/*
@@ -44,13 +45,13 @@ public interface NetworkCmProxyDataService {
* Get resource data for data store pass-through operational
* using dmi.
*
* @param cmHandle cm handle
* @param resourceIdentifier resource identifier
* @param acceptParamInHeader accept param
* @param optionsParamInQuery options query
* @return {@code Object} resource data
*/
- Object getResourceDataOperationalForCmHandle(String cmHandle,
+ Object getResourceDataOperationalForCmHandle(String cmHandleId,
String resourceIdentifier,
String acceptParamInHeader,
String optionsParamInQuery);
@@ -59,13 +60,13 @@ public interface NetworkCmProxyDataService {
* Get resource data for data store pass-through running
* using dmi.
*
* @param cmHandle cm handle
* @param resourceIdentifier resource identifier
* @param acceptParamInHeader accept param
* @param optionsParamInQuery options query
* @return {@code Object} resource data
*/
- Object getResourceDataPassThroughRunningForCmHandle(String cmHandle,
+ Object getResourceDataPassThroughRunningForCmHandle(String cmHandleId,
String resourceIdentifier,
String acceptParamInHeader,
String optionsParamInQuery);
@@ -73,14 +74,14 @@ public interface NetworkCmProxyDataService {
/**
* Write resource data for data store pass-through running
* using dmi for given cm-handle.
* @param cmHandle cm handle
* @param resourceIdentifier resource identifier
* @param operation required operation
* @param requestBody request body to create resource
* @param contentType content type in body
* @return {@code Object} return data
*/
- Object writeResourceDataPassThroughRunningForCmHandle(String cmHandle,
+ Object writeResourceDataPassThroughRunningForCmHandle(String cmHandleId,
String resourceIdentifier,
OperationEnum operation,
String requestBody,
@@ -89,10 +90,10 @@ public interface NetworkCmProxyDataService {
/**
* Retrieve module references for the given cm handle.
*
* @param cmHandle cm handle
* @return a collection of modules names and revisions
*/
- Collection<ModuleReference> getYangResourcesModuleReferences(String cmHandle);
+ Collection<ModuleReference> getYangResourcesModuleReferences(String cmHandleId);
/**
* Query cm handle identifiers for the given collection of module names.
@@ -103,4 +104,12 @@ public interface NetworkCmProxyDataService {
*/
Collection<String> executeCmHandleHasAllModulesSearch(Collection<String> moduleNames);
+ /**
+ * Query cm handle details by cm handle's name.
+ *
+ * @param cmHandleId cm handle identifier
+ * @return a collection of cm handle details.
+ */
+ NcmpServiceCmHandle getNcmpServiceCmHandle(String cmHandleId);
+
}
@@ -44,13 +45,13 @@ public interface NetworkCmProxyDataService {
* using dmi.
*
- * @param cmHandle cm handle
+ * @param cmHandleId cm handle identifier
* @param resourceIdentifier resource identifier
* @param acceptParamInHeader accept param
@@ -59,13 +60,13 @@ public interface NetworkCmProxyDataService {
* using dmi.
*
- * @param cmHandle cm handle
+ * @param cmHandleId cm handle identifier
* @param resourceIdentifier resource identifier
* @param acceptParamInHeader accept param
@@ -73,14 +74,14 @@ public interface NetworkCmProxyDataService {
* Write resource data for data store pass-through running
* using dmi for given cm-handle.
- * @param cmHandle cm handle
+ * @param cmHandleId cm handle identifier
* @param resourceIdentifier resource identifier
* @param operation required operation
@@ -89,10 +90,10 @@ public interface NetworkCmProxyDataService {
* Retrieve module references for the given cm handle.
*
- * @param cmHandle cm handle
+ * @param cmHandleId cm handle identifier
* @return a collection of modules names and revisions
*/